@@ -26,13 +26,7 @@
 #include <glib/gi18n-lib.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
-#ifdef HAVE_WEBKIT2
 #include <webkit2/webkit2.h>
-#else
-#include <webkit/webkit.h>
-#endif
-
-#include <libgd/gd.h>
 
 #include "dh-book-manager.h"
 #include "dh-book.h"
@@ -167,15 +161,11 @@ print_cb (GSimpleAction *action,
 {
         DhWindow *window = user_data;
         WebKitWebView *web_view = window_get_active_web_view (window);
-#ifdef HAVE_WEBKIT2
         WebKitPrintOperation *print_operation;
 
         print_operation = webkit_print_operation_new (web_view);
         webkit_print_operation_run_dialog (print_operation, GTK_WINDOW (window));
         g_object_unref (print_operation);
-#else
-        webkit_web_view_execute_script (web_view, "print();");
-#endif
 }
 
 static void
@@ -237,11 +227,7 @@ copy_cb (GSimpleAction *action,
                 WebKitWebView *web_view;
 
                 web_view = window_get_active_web_view (window);
-#ifdef HAVE_WEBKIT2
                 webkit_web_view_execute_editing_command (web_view, WEBKIT_EDITING_COMMAND_COPY);
-#else
-                webkit_web_view_copy_clipboard (web_view);
-#endif
         }
 }
 
@@ -252,23 +238,16 @@ find_cb (GSimpleAction *action,
 {
         DhWindow *window = user_data;
         DhWindowPriv  *priv;
-#ifndef HAVE_WEBKIT2
-        WebKitWebView *web_view;
-#endif
+
         priv = window->priv;
 
         gtk_widget_show (priv->findbar);
         gtk_widget_grab_focus (priv->findbar);
 
-#ifdef HAVE_WEBKIT2
         /* The behaviour for WebKit1 is to re-enable highlighting without
            starting a new search. WebKit2 API does not allow that
            without invoking a new search. */
         do_search (window);
-#else
-        web_view = window_get_active_web_view (window);
-        webkit_web_view_set_highlight_text_matches (web_view, TRUE);
-#endif /* HAVE_WEBKIT2 */
 }
 
 static void
@@ -475,6 +454,7 @@ static GActionEntry win_entries[] = {
         { "zoom-out",         zoom_out_cb,         NULL, NULL, NULL },
         { "zoom-default",     zoom_default_cb,     NULL, NULL, NULL },
         { "focus-search",     focus_search_cb,     NULL, NULL, NULL },
+        { "focus-search-alt", focus_search_cb,     NULL, NULL, NULL },
         /* go */
         { "go-back",          go_back_cb,          NULL, "false", NULL },
         { "go-forward",       go_forward_cb,       NULL, "false", NULL },
@@ -671,44 +651,62 @@ window_populate (DhWindow *window)
 {
         DhWindowPriv  *priv;
         DhBookManager *book_manager;
-        GtkWidget     *back;
-        GtkWidget     *forward;
+        GtkWidget     *back_button;
+        GtkWidget     *back_image;
+        GtkWidget     *forward_button;
+        GtkWidget     *forward_image;
         GtkWidget     *box;
         GtkWidget     *menu_button;
+        GtkWidget     *menu_image;
         GObject       *menu;
+        const char *prev_icon, *next_icon;
 
         priv = window->priv;
         book_manager = dh_app_peek_book_manager (DH_APP (gtk_window_get_application (GTK_WINDOW (window))));
 
-        // TODO: port to GtkHeaderBar in the future
-        priv->header_bar = gd_header_bar_new ();
+        priv->header_bar = gtk_header_bar_new ();
 
-        back = gd_header_simple_button_new ();
-        gd_header_button_set_label (GD_HEADER_BUTTON (back),
-                                    _("Back"));
-        gd_header_button_set_symbolic_icon_name (GD_HEADER_BUTTON (back),
-                                                 "go-previous-symbolic");
-        gtk_actionable_set_action_name (GTK_ACTIONABLE (back), "win.go-back");
+        if (gtk_widget_get_direction (GTK_WIDGET (window)) == GTK_TEXT_DIR_RTL) {
+                prev_icon = "go-previous-rtl-symbolic";
+                next_icon = "go-next-rtl-symbolic";
+        } else {
+                prev_icon = "go-previous-symbolic";
+                next_icon = "go-next-symbolic";
+        }
 
-        forward = gd_header_simple_button_new ();
-        gd_header_button_set_label (GD_HEADER_BUTTON (forward),
-                                    _("Forward"));
-        gd_header_button_set_symbolic_icon_name (GD_HEADER_BUTTON (forward),
-                                                 "go-next-symbolic");
-        gtk_actionable_set_action_name (GTK_ACTIONABLE (forward), "win.go-forward");
+        back_button = gtk_button_new ();
+        back_image = gtk_image_new_from_icon_name (prev_icon, GTK_ICON_SIZE_MENU);
+        gtk_button_set_image (GTK_BUTTON (back_button), back_image);
+        gtk_widget_set_tooltip_text (back_button, _("Back"));
+        gtk_actionable_set_action_name (GTK_ACTIONABLE (back_button), "win.go-back");
+        gtk_widget_set_valign (back_button, GTK_ALIGN_CENTER);
+        gtk_style_context_add_class (gtk_widget_get_style_context (back_button),
+				     "image-button");
+
+        forward_button = gtk_button_new ();
+        forward_image = gtk_image_new_from_icon_name (next_icon, GTK_ICON_SIZE_MENU);
+        gtk_button_set_image (GTK_BUTTON (forward_button), forward_image);
+        gtk_widget_set_tooltip_text (forward_button, _("Forward"));
+        gtk_actionable_set_action_name (GTK_ACTIONABLE (forward_button), "win.go-forward");
+        gtk_widget_set_valign (forward_button, GTK_ALIGN_CENTER);
+        gtk_style_context_add_class (gtk_widget_get_style_context (forward_button),
+				     "image-button");
 
         box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_style_context_add_class (gtk_widget_get_style_context (box), "linked");
-        gtk_box_pack_start (GTK_BOX (box), back, FALSE, FALSE, 0);
-        gtk_box_pack_start (GTK_BOX (box), forward, FALSE, FALSE, 0);
-        gd_header_bar_pack_start (GD_HEADER_BAR (priv->header_bar), box);
+        gtk_box_pack_start (GTK_BOX (box), back_button, FALSE, FALSE, 0);
+        gtk_box_pack_start (GTK_BOX (box), forward_button, FALSE, FALSE, 0);
+        gtk_header_bar_pack_start (GTK_HEADER_BAR (priv->header_bar), box);
 
-        menu_button = gd_header_menu_button_new ();
-        gd_header_button_set_symbolic_icon_name (GD_HEADER_BUTTON (menu_button),
-                                                 "emblem-system-symbolic");
+        menu_button = gtk_menu_button_new ();
+        menu_image = gtk_image_new_from_icon_name ("emblem-system-symbolic", GTK_ICON_SIZE_MENU);
+        gtk_button_set_image (GTK_BUTTON (menu_button), menu_image);
         gtk_actionable_set_action_name (GTK_ACTIONABLE (menu_button), "win.gear-menu");
+        gtk_widget_set_valign (menu_button, GTK_ALIGN_CENTER);
+        gtk_style_context_add_class (gtk_widget_get_style_context (menu_button),
+				     "image-button");
 
-        gd_header_bar_pack_end (GD_HEADER_BAR (priv->header_bar), menu_button);
+        gtk_header_bar_pack_end (GTK_HEADER_BAR (priv->header_bar), menu_button);
 
         menu = gtk_builder_get_object (priv->builder, "window-menu");
         gtk_menu_button_set_menu_model (GTK_MENU_BUTTON (menu_button), G_MENU_MODEL (menu));
@@ -828,48 +826,26 @@ find_library_equivalent (DhWindow    *window,
         return local_uri;
 }
 
-#ifdef HAVE_WEBKIT2
 static gboolean
 window_web_view_decide_policy_cb (WebKitWebView           *web_view,
                                   WebKitPolicyDecision    *policy_decision,
                                   WebKitPolicyDecisionType type,
                                   DhWindow                *window)
-#else
-static gboolean
-window_web_view_navigation_policy_decision_requested (WebKitWebView             *web_view,
-                                                      WebKitWebFrame            *frame,
-                                                      WebKitNetworkRequest      *request,
-                                                      WebKitWebNavigationAction *navigation_action,
-                                                      WebKitWebPolicyDecision   *policy_decision,
-                                                      DhWindow                  *window)
-#endif
 {
         const char   *uri;
-#ifdef HAVE_WEBKIT2
         WebKitNavigationPolicyDecision *navigation_decision;
-#endif
 
-
-#ifdef HAVE_WEBKIT2
         if (type != WEBKIT_POLICY_DECISION_TYPE_NAVIGATION_ACTION)
                 return FALSE;
 
         navigation_decision = WEBKIT_NAVIGATION_POLICY_DECISION (policy_decision);
         uri = webkit_uri_request_get_uri (webkit_navigation_policy_decision_get_request (navigation_decision));
-#else
-        uri = webkit_network_request_get_uri (request);
-#endif
 
         /* make sure to hide the info bar on page change */
         gtk_widget_hide (window_get_active_info_bar (window));
 
-#ifdef HAVE_WEBKIT2
         if (webkit_navigation_policy_decision_get_mouse_button (navigation_decision) == 2) { /* middle click */
                 webkit_policy_decision_ignore (policy_decision);
-#else
-        if (webkit_web_navigation_action_get_button (navigation_action) == 2) { /* middle click */
-                webkit_web_policy_decision_ignore (policy_decision);
-#endif
                 g_signal_emit (window, signals[OPEN_LINK], 0, uri, DH_OPEN_LINK_NEW_TAB);
                 return TRUE;
         }
@@ -881,11 +857,7 @@ window_web_view_navigation_policy_decision_requested (WebKitWebView
         if (strncmp (uri, "http://library.gnome.org/devel/", 31) == 0) {
                 gchar *local_uri = find_library_equivalent (window, uri);
                 if (local_uri) {
-#ifdef HAVE_WEBKIT2
                         webkit_policy_decision_ignore (policy_decision);
-#else
-                        webkit_web_policy_decision_ignore (policy_decision);
-#endif
                         _dh_window_display_uri (window, local_uri);
                         g_free (local_uri);
                         return TRUE;
@@ -893,30 +865,14 @@ window_web_view_navigation_policy_decision_requested (WebKitWebView
         }
 
         if (strncmp (uri, "file://", 7) != 0) {
-#ifdef HAVE_WEBKIT2
                 webkit_policy_decision_ignore (policy_decision);
-#else
-                webkit_web_policy_decision_ignore (policy_decision);
-#endif
                 gtk_show_uri (NULL, uri, GDK_CURRENT_TIME, NULL);
                 return TRUE;
         }
 
-#ifndef HAVE_WEBKIT2
-        /* We already do this in load_changed_cb() for webkit2 */
-        if (web_view == window_get_active_web_view (window)) {
-                DhWindowPriv *priv;
-
-                priv = window->priv;
-                dh_sidebar_select_uri (DH_SIDEBAR (priv->sidebar), uri);
-                window_check_history (window, web_view);
-        }
-#endif
-
         return FALSE;
 }
 
-#ifdef HAVE_WEBKIT2
 static void
 window_web_view_load_changed_cb (WebKitWebView   *web_view,
                                  WebKitLoadEvent  load_event,
@@ -934,23 +890,13 @@ window_web_view_load_changed_cb (WebKitWebView   *web_view,
         dh_sidebar_select_uri (DH_SIDEBAR (priv->sidebar), uri);
         window_check_history (window, web_view);
 }
-#endif
 
-#ifdef HAVE_WEBKIT2
 static gboolean
 window_web_view_load_failed_cb (WebKitWebView   *web_view,
                                 WebKitLoadEvent  load_event,
                                 const gchar     *uri,
                                 GError          *web_error,
                                 DhWindow        *window)
-#else
-static gboolean
-window_web_view_load_error_cb (WebKitWebView  *web_view,
-                               WebKitWebFrame *frame,
-                               gchar          *uri,
-                               GError         *web_error,
-                               DhWindow       *window)
-#endif
 {
         GtkWidget *info_bar;
         GtkWidget *content_area;
@@ -1051,7 +997,6 @@ static gboolean
 do_search (DhWindow *window)
 {
         DhWindowPriv         *priv = window->priv;
-#ifdef HAVE_WEBKIT2
         WebKitFindController *find_controller;
         guint                 find_options = WEBKIT_FIND_OPTIONS_WRAP_AROUND;
         const gchar          *search_text;
@@ -1062,23 +1007,6 @@ do_search (DhWindow *window)
 
         search_text = egg_find_bar_get_search_string (EGG_FIND_BAR (priv->findbar));
         webkit_find_controller_search (find_controller, search_text, find_options, G_MAXUINT);
-#else
-        WebKitWebView *web_view;
-
-        web_view = window_get_active_web_view (window);
-
-        webkit_web_view_unmark_text_matches (web_view);
-        webkit_web_view_mark_text_matches (
-                web_view,
-                egg_find_bar_get_search_string (EGG_FIND_BAR (priv->findbar)),
-                egg_find_bar_get_case_sensitive (EGG_FIND_BAR (priv->findbar)), 0);
-        webkit_web_view_set_highlight_text_matches (web_view, TRUE);
-
-        webkit_web_view_search_text (
-                web_view, egg_find_bar_get_search_string (EGG_FIND_BAR (priv->findbar)),
-                egg_find_bar_get_case_sensitive (EGG_FIND_BAR (priv->findbar)),
-                TRUE, TRUE);
-#endif /* HAVE_WEBKIT2 */
 
         priv->find_source_id = 0;
 
@@ -1105,23 +1033,7 @@ window_find_case_changed_cb (GObject    *object,
                              GParamSpec *pspec,
                              DhWindow   *window)
 {
-#ifdef HAVE_WEBKIT2
         do_search (window);
-#else
-        DhWindowPriv  *priv = window->priv;;
-        WebKitWebView *view;
-        const gchar   *string;
-        gboolean       case_sensitive;
-
-        view = window_get_active_web_view (window);
-
-        string = egg_find_bar_get_search_string (EGG_FIND_BAR (priv->findbar));
-        case_sensitive = egg_find_bar_get_case_sensitive (EGG_FIND_BAR (priv->findbar));
-
-        webkit_web_view_unmark_text_matches (view);
-        webkit_web_view_mark_text_matches (view, string, case_sensitive, 0);
-        webkit_web_view_set_highlight_text_matches (view, TRUE);
-#endif
 }
 
 static void
@@ -1129,23 +1041,14 @@ findbar_find_next (DhWindow *window)
 {
         DhWindowPriv         *priv = window->priv;
         WebKitWebView        *view;
-#ifdef HAVE_WEBKIT2
         WebKitFindController *find_controller;
-#else
-        const gchar          *string;
-        gboolean              case_sensitive;
-#endif
+
         view = window_get_active_web_view (window);
 
         gtk_widget_show (priv->findbar);
-#ifdef HAVE_WEBKIT2
+
         find_controller = webkit_web_view_get_find_controller (view);
         webkit_find_controller_search_next(find_controller);
-#else
-        string = egg_find_bar_get_search_string (EGG_FIND_BAR (priv->findbar));
-        case_sensitive = egg_find_bar_get_case_sensitive (EGG_FIND_BAR (priv->findbar));
-        webkit_web_view_search_text (view, string, case_sensitive, TRUE, TRUE);
-#endif
 }
 
 static void
@@ -1160,24 +1063,14 @@ findbar_find_previous (DhWindow *window)
 {
         DhWindowPriv         *priv = window->priv;
         WebKitWebView        *view;
-#ifdef HAVE_WEBKIT2
         WebKitFindController *find_controller;
-#else
-        const gchar          *string;
-        gboolean             case_sensitive;
-#endif
+
         view = window_get_active_web_view (window);
 
         gtk_widget_show (priv->findbar);
 
-#ifdef HAVE_WEBKIT2
         find_controller = webkit_web_view_get_find_controller (view);
         webkit_find_controller_search_previous(find_controller);
-#else
-        string = egg_find_bar_get_search_string (EGG_FIND_BAR (priv->findbar));
-        case_sensitive = egg_find_bar_get_case_sensitive (EGG_FIND_BAR (priv->findbar));
-        webkit_web_view_search_text (view, string, case_sensitive, FALSE, TRUE);
-#endif
 }
 
 static void
@@ -1193,18 +1086,14 @@ window_findbar_close_cb (GtkWidget *widget,
 {
         DhWindowPriv         *priv = window->priv;
         WebKitWebView        *view;
-#ifdef HAVE_WEBKIT2
         WebKitFindController *find_controller;
-#endif
+
         view = window_get_active_web_view (window);
 
         gtk_widget_hide (priv->findbar);
-#ifdef HAVE_WEBKIT2
+
         find_controller = webkit_web_view_get_find_controller (view);
         webkit_find_controller_search_finish (find_controller);
-#else
-        webkit_web_view_set_highlight_text_matches (view, FALSE);
-#endif
 }
 
 #if 0
@@ -1256,9 +1145,6 @@ window_open_new_tab (DhWindow    *window,
         GtkWidget    *info_bar;
         gchar *font_fixed = NULL;
         gchar *font_variable = NULL;
-#ifndef HAVE_WEBKIT2
-        GtkWidget    *scrolled_window;
-#endif
 
         priv = window->priv;
 
@@ -1301,18 +1187,7 @@ window_open_new_tab (DhWindow    *window,
         g_object_set_data (G_OBJECT (vbox), "info_bar", info_bar);
 
         gtk_box_pack_start (GTK_BOX(vbox), info_bar, FALSE, TRUE, 0);
-
-#ifdef HAVE_WEBKIT2
         gtk_box_pack_start (GTK_BOX(vbox), view, TRUE, TRUE, 0);
-#else
-        scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-        gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
-                                        GTK_POLICY_AUTOMATIC,
-                                        GTK_POLICY_AUTOMATIC);
-        gtk_container_add (GTK_CONTAINER (scrolled_window), view);
-        gtk_widget_show (scrolled_window);
-        gtk_box_pack_start (GTK_BOX(vbox), scrolled_window, TRUE, TRUE, 0);
-#endif
 
         label = window_new_tab_label (window, _("Empty Page"), vbox);
         gtk_widget_show_all (label);
@@ -1323,32 +1198,21 @@ window_open_new_tab (DhWindow    *window,
         g_signal_connect (view, "button-press-event",
                           G_CALLBACK (window_web_view_button_press_event_cb),
                           window);
-#ifdef HAVE_WEBKIT2
         g_signal_connect (view, "decide-policy",
                           G_CALLBACK (window_web_view_decide_policy_cb),
                           window);
-#else
-        g_signal_connect (view, "navigation-policy-decision-requested",
-                          G_CALLBACK (window_web_view_navigation_policy_decision_requested),
-                          window);
-#endif
-#ifdef HAVE_WEBKIT2
         g_signal_connect (view, "load-changed",
                           G_CALLBACK (window_web_view_load_changed_cb),
                           window);
         g_signal_connect (view, "load-failed",
                           G_CALLBACK (window_web_view_load_failed_cb),
                           window);
-#else
-        g_signal_connect (view, "load-error",
-                          G_CALLBACK (window_web_view_load_error_cb),
-                          window);
-#endif
 
         num = gtk_notebook_append_page (GTK_NOTEBOOK (priv->notebook),
                                         vbox, NULL);
         gtk_container_child_set (GTK_CONTAINER (priv->notebook), vbox,
                                  "tab-expand", TRUE,
+                                 "reorderable", TRUE,
                                  NULL);
         gtk_notebook_set_tab_label (GTK_NOTEBOOK (priv->notebook),
                                     vbox, label);
@@ -1481,7 +1345,7 @@ window_update_title (DhWindow      *window,
                 web_view_title = NULL;
         }
 
-        gd_header_bar_set_title (GD_HEADER_BAR (priv->header_bar),
+        gtk_header_bar_set_title (GTK_HEADER_BAR (priv->header_bar),
                                  web_view_title);
 }
 
